@@ -7,5 +7,5 @@ This the top level __init__.py
 """
 
 __author__ = """Joaquim Ramos de Carvalho"""
-__email__ = 'joaquim@uc.pt'
-__version__ = '0.2.8'
+__email__ = "joaquim@uc.pt"
+__version__ = '0.3.0'
